@@ -109,6 +109,44 @@ QString ObjectTreeParser::htmlContent()
     return content;
 }
 
+bool ObjectTreeParser::hasEncryptedParts() const
+{
+    bool result = false;
+
+    ::collect(
+        mParsedPart,
+        [](const MessagePart::Ptr &) {
+            return true;
+        },
+        [&result](const MessagePart::Ptr &part) {
+            if (const auto enc = dynamic_cast<MimeTreeParser::EncryptedMessagePart *>(part.data())) {
+                result = true;
+            }
+            return false;
+        });
+
+    return result;
+}
+
+bool ObjectTreeParser::hasSignedParts() const
+{
+    bool result = false;
+
+    ::collect(
+        mParsedPart,
+        [](const MessagePart::Ptr &) {
+            return true;
+        },
+        [&result](const MessagePart::Ptr &part) {
+            if (const auto enc = dynamic_cast<MimeTreeParser::SignedMessagePart *>(part.data())) {
+                result = true;
+            }
+            return false;
+        });
+
+    return result;
+}
+
 static void print(QTextStream &stream, KMime::Content *node, const QString prefix = {})
 {
     QByteArray mediaType("text");
@@ -245,11 +283,6 @@ MessagePart::List ObjectTreeParser::collectAttachmentParts()
     return contentParts;
 }
 
-void ObjectTreeParser::decryptParts()
-{
-    decryptAndVerify();
-}
-
 /*
  * This naive implementation assumes that there is an encrypted part wrapping a signature.
  * For other cases we would have to process both recursively (I think?)
